from rollerverbrauch import db
from flask.ext.security import UserMixin, RoleMixin

roles_users = db.Table('roles_users',
                       db.Column('user_id', db.Integer(), db.ForeignKey('user.id')),
                       db.Column('role_id', db.Integer(), db.ForeignKey('role.id')))


class Role(db.Model, RoleMixin):
    id = db.Column(db.Integer(), primary_key=True)
    name = db.Column(db.String(80), unique=True)
    description = db.Column(db.String(255))

    def __str__(self):
        return self.name

    def __hash__(self):
        return hash(self.name)


class User(db.Model, UserMixin):
    id = db.Column(db.Integer, primary_key=True)
    email = db.Column(db.String(255), unique=True)
    password = db.Column(db.String(255))
    active = db.Column(db.Boolean())
    confirmed_at = db.Column(db.DateTime())
    vehicles = db.relationship(
        'Vehicle'
    )
    roles = db.relationship(
        'Role',
        secondary=roles_users,
        backref=db.backref('users', lazy='dynamic')
    )

    def __repr__(self):
        return '<User id="%r" email="%r" ' % (self.id, self.email)


class Vehicle(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    owner_id = db.Column(db.Integer, db.ForeignKey('user.id'))
    name = db.Column(db.String(255), unique=True)
    pitstops = db.relationship(
        'Pitstop'
    )

    def __init__(self, name):
        self.name = name

    def __repr__(self):
        return '<Vehicle id="%r" owner_id="%r" name="%r" />' % (self.id, self.owner_id, self.name)


class Pitstop(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    date = db.Column(db.Date)
    odometer = db.Column(db.Integer)
    litres = db.Column(db.Numeric(5, 2))
    vehicle_id = db.Column(db.Integer, db.ForeignKey('vehicle.id'))

    def __init__(self, odometer, litres, date):
        self.odometer = odometer
        self.litres = litres
        self.date = date

    def __repr__(self):
        return '<Pitstop odometer="%r" litres="%r" date="%r" vehicle_id="%r">' % (self.odometer, self.litres, self.date, self.vehicle_id)